@@ -35,7 +35,11 @@ def get_secret_string(
             return secret_string_maybe
         else:
             LOG.error(
-                f"Could not read secret {secret_id} becasue GetSecretValueResponse does not have a SecretString field. The secret might be binary instead of string."
+                f"""
+                    Could not read secret {secret_id} becasue
+                    GetSecretValueResponse does not have a SecretString field.
+                    The secret might be binary instead of string.
+                """
             )
             return None
     except Exception as ex:
@@ -55,7 +59,11 @@ def get_secret_binary(
             return secret_bytes_maybe
         else:
             LOG.error(
-                f"Could not read secret {secret_id} becasue GetSecretValueResponse does not have a SecretBinary field. The secret might be string instead of bytes."
+                f"""
+                    Could not read secret {secret_id} becasue
+                    GetSecretValueResponse does not have a SecretBinary field.
+                    The secret might be string instead of bytes.
+                """
             )
             return None
     except Exception as ex:
@@ -129,13 +137,13 @@ def delete_s3_object(
 
 
 def save_to_s3(
-    client: S3Client,
+    s3_client: S3Client,
     bucket: str,
     key: str,
     body: str,
 ) -> Optional[PutObjectOutputTypeDef]:
     try:
-        return client.put_object(Bucket=bucket, Key=key, Body=body)
+        return s3_client.put_object(Bucket=bucket, Key=key, Body=body)
     except Exception as ex:
         LOG.error(f"Could not put object bucket: {bucket} key: {key} becasue of {ex}")
         return None
@@ -147,12 +155,31 @@ def save_to_s3(
 
 
 def send_sqs_message(
-    client: SQSClient, queue_url: str, message_body: str
+    sqs_client: SQSClient, queue_url: str, message_body: str
 ) -> Optional[SendMessageResultTypeDef]:
     try:
-        return client.send_message(QueueUrl=queue_url, MessageBody=message_body)
+        return sqs_client.send_message(QueueUrl=queue_url, MessageBody=message_body)
     except Exception as ex:
         LOG.error(
             f"Could not send SQS message {message_body} to queue_url: {queue_url} becasue of {ex}"
         )
         return None
+
+
+def send_sqs_message_fifo(
+    sqs_client: SQSClient, queue_url: str, message_body: str, message_group_id: str
+) -> Optional[SendMessageResultTypeDef]:
+    try:
+        return sqs_client.send_message(
+            QueueUrl=queue_url,
+            MessageBody=message_body,
+            MessageGroupId=message_group_id,
+        )
+    except Exception as ex:
+        LOG.error(
+            f"""Could not send SQS message {message_body}
+                to queue_url: {queue_url}
+                message_group_id: {message_group_id} becasue of {ex}
+            """
+        )
+        return None
