@@ -5,6 +5,7 @@ import re
 import tomli
 from fastapi import APIRouter
 from fastapi.responses import JSONResponse
+from pydantic import BaseModel
 
 LOG = logging.getLogger(__name__)
 
@@ -42,7 +43,11 @@ def get_current_version():
         return None
 
 
-@router.get("")
+class Version(BaseModel):
+    version: str
+
+
+@router.get("", response_model=Version)
 async def get_version():
     current_version = get_current_version()
     LOG.info(f"The current version is {current_version}")
