@@ -1,6 +1,7 @@
 import logging
 import time
 from typing import Any, Dict, Optional
+from xmlrpc.client import Boolean
 
 import jwt
 from ecdsa import SigningKey, VerifyingKey
@@ -57,8 +58,8 @@ def decode_jwt(
 
     try:
         return jwt.decode(
-            jwt_string,
-            verifying_key.to_pem(),
+            jwt=jwt_string,
+            key=verifying_key.to_pem(),
             algorithms=[algorithm],
             audience=audience,
         )
@@ -72,10 +73,12 @@ def is_valid_jwt(
     verifying_key: VerifyingKey,
     audience: str,
     algorithm=DEFAULT_ALGORITHM,
-):
+) -> bool:
     try:
         decoded = decode_jwt(jwt_string, verifying_key, audience, algorithm)
         if decoded:
             return True
+        else:
+            return False
     except Exception as _ex:
         return False
